@@ -184,6 +184,8 @@ import javax.xml.datatype.XMLGregorianCalendar;
     "faxBusiness",
     "faxHome",
     "faxOther",
+    "filestoreId",
+    "filestoreName",
     "folderTree",
     "givenName",
     "guiPreferencesForSoap",
@@ -204,10 +206,10 @@ import javax.xml.datatype.XMLGregorianCalendar;
     "mailFolderSentName",
     "mailFolderSpamName",
     "mailFolderTrashName",
-    "mailFolderArchiveFullName",
     "mailenabled",
     "managerName",
     "maritalStatus",
+    "maxQuota",
     "middleName",
     "name",
     "nickname",
@@ -260,6 +262,7 @@ import javax.xml.datatype.XMLGregorianCalendar;
     "uploadFileSizeLimit",
     "uploadFileSizeLimitPerFile",
     "url",
+    "usedQuota",
     "userAttributes",
     "userfield01",
     "userfield02",
@@ -344,6 +347,10 @@ public class User {
     @XmlElement(name = "fax_other", nillable = true)
     protected String faxOther;
     @XmlElement(nillable = true)
+    protected Integer filestoreId;
+    @XmlElement(name = "filestore_name", nillable = true)
+    protected String filestoreName;
+    @XmlElement(nillable = true)
     protected Integer folderTree;
     @XmlElement(name = "given_name", nillable = true)
     protected String givenName;
@@ -382,14 +389,14 @@ public class User {
     protected String mailFolderSpamName;
     @XmlElement(name = "mail_folder_trash_name", nillable = true)
     protected String mailFolderTrashName;
-    @XmlElement(name = "mail_folder_archive_full_name", nillable = true)
-    protected String mailFolderArchiveFullName;
     @XmlElement(nillable = true)
     protected Boolean mailenabled;
     @XmlElement(name = "manager_name", nillable = true)
     protected String managerName;
     @XmlElement(name = "marital_status", nillable = true)
     protected String maritalStatus;
+    @XmlElement(nillable = true)
+    protected Long maxQuota;
     @XmlElement(name = "middle_name", nillable = true)
     protected String middleName;
     @XmlElement(nillable = true)
@@ -494,6 +501,8 @@ public class User {
     @XmlElement(nillable = true)
     protected String url;
     @XmlElement(nillable = true)
+    protected Long usedQuota;
+    @XmlElement(nillable = true)
     protected SOAPStringMapMap userAttributes;
     @XmlElement(nillable = true)
     protected String userfield01;
@@ -1243,6 +1252,54 @@ public class User {
         this.faxOther = value;
     }
 
+    /**
+     * Ruft den Wert der filestoreId-Eigenschaft ab.
+     *
+     * @return
+     *     possible object is
+     *     {@link Integer }
+     *
+     */
+    public Integer getFilestoreId() {
+        return filestoreId;
+    }
+
+    /**
+     * Legt den Wert der filestoreId-Eigenschaft fest.
+     *
+     * @param value
+     *     allowed object is
+     *     {@link Integer }
+     *
+     */
+    public void setFilestoreId(Integer value) {
+        this.filestoreId = value;
+    }
+
+    /**
+     * Ruft den Wert der filestoreName-Eigenschaft ab.
+     *
+     * @return
+     *     possible object is
+     *     {@link String }
+     *
+     */
+    public String getFilestoreName() {
+        return filestoreName;
+    }
+
+    /**
+     * Legt den Wert der filestoreName-Eigenschaft fest.
+     *
+     * @param value
+     *     allowed object is
+     *     {@link String }
+     *
+     */
+    public void setFilestoreName(String value) {
+        this.filestoreName = value;
+    }
+
     /**
      * Ruft den Wert der folderTree-Eigenschaft ab.
      *
@@ -1723,31 +1780,6 @@ public class User {
         this.mailFolderTrashName = value;
     }
 
-    /**
-     * Ruft den Wert der mailFolderArchiveFullName-Eigenschaft ab.
-     *
-     * @return
-     *     possible object is
-     *     {@link String }
-     *
-     */
-    public String getMailFolderArchiveFullName() {
-        return mailFolderArchiveFullName;
-    }
-
-    /**
-     * Legt den Wert der mailFolderArchiveFullName-Eigenschaft fest.
-     *
-     * @param value
-     *     allowed object is
-     *     {@link String }
-     *
-     */
-    public void setMailFolderArchiveFullName(String value) {
-        this.mailFolderArchiveFullName = value;
-    }
-
-
     /**
      * Ruft den Wert der mailenabled-Eigenschaft ab.
      *
@@ -1820,6 +1852,30 @@ public class User {
         this.maritalStatus = value;
     }
 
+    /**
+     * Ruft den Wert der maxQuota-Eigenschaft ab.
+     *
+     * @return
+     *     possible object is
+     *     {@link Long }
+     *
+     */
+    public Long getMaxQuota() {
+        return maxQuota;
+    }
+
+    /**
+     * Legt den Wert der maxQuota-Eigenschaft fest.
+     *
+     * @param value
+     *     allowed object is
+     *     {@link Long }
+     *
+     */
+    public void setMaxQuota(Long value) {
+        this.maxQuota = value;
+    }
+
     /**
      * Ruft den Wert der middleName-Eigenschaft ab.
      *
@@ -3068,6 +3124,30 @@ public class User {
         this.url = value;
     }
 
+    /**
+     * Ruft den Wert der usedQuota-Eigenschaft ab.
+     *
+     * @return
+     *     possible object is
+     *     {@link Long }
+     *
+     */
+    public Long getUsedQuota() {
+        return usedQuota;
+    }
+
+    /**
+     * Legt den Wert der usedQuota-Eigenschaft fest.
+     *
+     * @param value
+     *     allowed object is
+     *     {@link Long }
+     *
+     */
+    public void setUsedQuota(Long value) {
+        this.usedQuota = value;
+    }
+
     /**
      * Ruft den Wert der userAttributes-Eigenschaft ab.
      *
